@@ -16,6 +16,9 @@
 # limitations under the License.
 
 
+from __future__ import annotations
+
+import typing as t
 from enum import Enum
 from logging import getLogger
 from ssl import SSLSocket
@@ -33,7 +36,10 @@ from ...exceptions import (
     NotALeader,
     ServiceUnavailable,
 )
-from ._bolt import AsyncBolt
+from ._bolt import (
+    AsyncBolt,
+    ServerStateManagerBase,
+)
 from ._common import (
     check_supported_server_product,
     CommitResponse,
@@ -53,8 +59,8 @@ class ServerStates(Enum):
     FAILED = "FAILED"
 
 
-class ServerStateManager:
-    _STATE_TRANSITIONS = {
+class ServerStateManager(ServerStateManagerBase):
+    _STATE_TRANSITIONS: t.Dict[Enum, t.Dict[str, Enum]] = {
         ServerStates.CONNECTED: {
             "hello": ServerStates.READY,
         },
@@ -91,6 +97,9 @@ class ServerStateManager:
         if state_before != self.state and callable(self._on_change):
             self._on_change(state_before, self.state)
 
+    def failed(self):
+        return self.state == ServerStates.FAILED
+
 
 class AsyncBolt3(AsyncBolt):
     """ Protocol handler for Bolt 3.
@@ -104,6 +113,8 @@ class AsyncBolt3(AsyncBolt):
 
     supports_multiple_databases = False
 
+    supports_re_auth = False
+
     supports_notification_filtering = False
 
     def __init__(self, *args, **kwargs):
@@ -116,6 +127,9 @@ class AsyncBolt3(AsyncBolt):
         log.debug("[#%04X]  _: <CONNECTION> state: %s > %s", self.local_port,
                   old_state.name, new_state.name)
 
+    def _get_server_state_manager(self) -> ServerStateManagerBase:
+        return self._server_state_manager
+
     @property
     def is_reset(self):
         # We can't be sure of the server's state if there are still pending
@@ -159,6 +173,14 @@ class AsyncBolt3(AsyncBolt):
         await self.fetch_all()
         check_supported_server_product(self.server_info.agent)
 
+    def logon(self, dehydration_hooks=None, hydration_hooks=None):
+        """Append a LOGON message to the outgoing queue."""
+        self.assert_re_auth_support()
+
+    def logoff(self, dehydration_hooks=None, hydration_hooks=None):
+        """Append a LOGOFF message to the outgoing queue."""
+        self.assert_re_auth_support()
+
     async def route(
         self, database=None, imp_user=None, bookmarks=None,
         dehydration_hooks=None, hydration_hooks=None
@@ -397,8 +419,7 @@ class AsyncBolt3(AsyncBolt):
                     self.pool.on_write_failure(address=self.unresolved_address)
                 raise
             except Neo4jError as e:
-                if self.pool and e._invalidates_all_connections():
-                    await self.pool.mark_all_stale()
+                await self.pool.on_neo4j_error(e, self)
                 raise
         else:
             raise BoltProtocolError("Unexpected response message with signature %02X" % summary_signature, address=self.unresolved_address)
