@@ -16,13 +16,18 @@
 # limitations under the License.
 
 
+from __future__ import annotations
+
 import abc
 import asyncio
 import logging
+import typing as t
 from collections import (
     defaultdict,
     deque,
 )
+from copy import copy
+from dataclasses import dataclass
 from logging import getLogger
 from random import choice
 
@@ -32,6 +37,7 @@ from ..._async_compat.concurrency import (
     AsyncRLock,
 )
 from ..._async_compat.network import AsyncNetworkUtil
+from ..._async_compat.util import AsyncUtil
 from ..._conf import (
     PoolConfig,
     WorkspaceConfig,
@@ -42,10 +48,15 @@ from ..._deadline import (
 )
 from ..._exceptions import BoltError
 from ..._routing import RoutingTable
+from ..._sync.auth_management import StaticAuthManager
 from ...api import (
     READ_ACCESS,
     WRITE_ACCESS,
 )
+from ...auth_management import (
+    AsyncAuthManager,
+    AuthManager,
+)
 from ...exceptions import (
     ClientError,
     ConfigurationError,
@@ -54,8 +65,11 @@ from ...exceptions import (
     ReadServiceUnavailable,
     ServiceUnavailable,
     SessionExpired,
+    TokenExpired,
+    TokenExpiredRetryable,
     WriteServiceUnavailable,
 )
+from ..auth_management import AsyncStaticAuthManager
 from ._bolt import AsyncBolt
 
 
@@ -63,6 +77,12 @@ from ._bolt import AsyncBolt
 log = getLogger("neo4j")
 
 
+@dataclass
+class AcquireAuth:
+    auth: t.Union[AsyncAuthManager, AuthManager, None]
+    force_auth: bool = False
+
+
 class AsyncIOPool(abc.ABC):
     """ A collection of connections to one or more server addresses.
     """
@@ -86,6 +106,9 @@ class AsyncIOPool(abc.ABC):
     async def __aexit__(self, exc_type, exc_value, traceback):
         await self.close()
 
+    async def get_auth(self):
+        return await AsyncUtil.callback(self.pool_config.auth.get_auth)
+
     async def _acquire_from_pool(self, address):
         with self.lock:
             for connection in list(self.connections.get(address, [])):
@@ -96,6 +119,22 @@ class AsyncIOPool(abc.ABC):
                 return connection
         return None  # no free connection available
 
+    def _remove_connection(self, connection):
+        address = connection.unresolved_address
+        with self.lock:
+            log.debug(
+                "[#%04X]  _: <POOL> remove connection from pool %r %s",
+                connection.local_port, address, connection.connection_id
+            )
+            try:
+                self.connections.get(address, []).remove(connection)
+            except ValueError:
+                # If closure fails (e.g. because the server went
+                # down), all connections to the same address will
+                # be removed. Therefore, we silently ignore if the
+                # connection isn't in the pool anymore.
+                pass
+
     async def _acquire_from_pool_checked(
         self, address, health_check, deadline
     ):
@@ -110,35 +149,40 @@ class AsyncIOPool(abc.ABC):
                 # `stale` but still alive.
                 if log.isEnabledFor(logging.DEBUG):
                     log.debug(
-                        "[#%04X]  _: <POOL> removing old connection %s "
+                        "[#%04X]  _: <POOL> found unhealthy connection %s "
                         "(closed=%s, defunct=%s, stale=%s, in_use=%s)",
                         connection.local_port, connection.connection_id,
                         connection.closed(), connection.defunct(),
                         connection.stale(), connection.in_use
                     )
                 await connection.close()
-                with self.lock:
-                    try:
-                        self.connections.get(address, []).remove(connection)
-                    except ValueError:
-                        # If closure fails (e.g. because the server went
-                        # down), all connections to the same address will
-                        # be removed. Therefore, we silently ignore if the
-                        # connection isn't in the pool anymore.
-                        pass
+                self._remove_connection(connection)
                 continue  # try again with a new connection
             else:
                 return connection
 
-    def _acquire_new_later(self, address, deadline):
+    def _acquire_new_later(self, address, auth, deadline):
         async def connection_creator():
             released_reservation = False
             try:
                 try:
-                    connection = await self.opener(address, deadline)
+                    connection = await self.opener(
+                        address, auth or self.pool_config.auth, deadline
+                    )
                 except ServiceUnavailable:
                     await self.deactivate(address)
                     raise
+                if auth:
+                    # It's unfortunate that we have to create a connection
+                    # first to determine if the session-level auth is supported
+                    # by the protocol or not.
+                    try:
+                        connection.assert_re_auth_support()
+                    except ConfigurationError:
+                        log.debug("[#%04X]  _: <POOL> no re-auth support",
+                                  connection.local_port)
+                        await connection.close()
+                        raise
                 connection.pool = self
                 connection.in_use = True
                 with self.lock:
@@ -164,13 +208,47 @@ class AsyncIOPool(abc.ABC):
                 return connection_creator
         return None
 
-    async def _acquire(self, address, deadline, liveness_check_timeout):
+    async def _re_auth_connection(self, connection, auth, force):
+        if auth:
+            # Assert session auth is supported by the protocol.
+            # The Bolt implementation will try as hard as it can to make the
+            # re-auth work. So if the session auth token is identical to the
+            # driver auth token, the connection doesn't have to do anything so
+            # it won't fail regardless of the protocol version.
+            connection.assert_re_auth_support()
+        new_auth_manager = auth or self.pool_config.auth
+        log_auth = "******" if auth else "None"
+        new_auth = await AsyncUtil.callback(new_auth_manager.get_auth)
+        try:
+            updated = connection.re_auth(new_auth, new_auth_manager,
+                                         force=force)
+            log.debug("[#%04X]  _: <POOL> checked re_auth auth=%s updated=%s "
+                      "force=%s",
+                      connection.local_port, log_auth, updated, force)
+        except Exception as exc:
+            log.debug("[#%04X]  _: <POOL> check re_auth failed %r auth=%s "
+                      "force=%s",
+                      connection.local_port, exc, log_auth, force)
+            raise
+        assert not force or updated  # force=True implies updated=True
+        if force:
+            await connection.send_all()
+            await connection.fetch_all()
+
+    async def _acquire(
+        self, address, auth, deadline, liveness_check_timeout
+    ):
         """ Acquire a connection to a given address from the pool.
         The address supplied should always be an IP address, not
         a host name.
 
         This method is thread safe.
         """
+        if auth is None:
+            auth = AcquireAuth(None)
+        force_auth = auth.force_auth
+        auth = auth.auth
+
         async def health_check(connection_, deadline_):
             if (connection_.closed()
                     or connection_.defunct()
@@ -193,13 +271,33 @@ class AsyncIOPool(abc.ABC):
                 address, health_check, deadline
             )
             if connection:
-                log.debug("[#%04X]  _: <POOL> handing out existing connection "
-                          "%s", connection.local_port,
-                          connection.connection_id)
+                log.debug("[#%04X]  _: <POOL> picked existing connection %s",
+                          connection.local_port, connection.connection_id)
+                try:
+                    await self._re_auth_connection(
+                        connection, auth, force_auth
+                    )
+                except ConfigurationError:
+                    if auth:
+                        # protocol version lacks support for re-auth
+                        # => session auth token is not supported
+                        raise
+                    # expiring tokens supported by flushing the pool
+                    # => give up this connection
+                    log.debug("[#%04X]  _: <POOL> backwards compatible "
+                              "auth token refresh: purge connection",
+                              connection.local_port)
+                    await connection.close()
+                    await self.release(connection)
+                    continue
+                log.debug("[#%04X]  _: <POOL> handing out existing connection",
+                          connection.local_port)
                 return connection
             # all connections in pool are in-use
             with self.lock:
-                connection_creator = self._acquire_new_later(address, deadline)
+                connection_creator = self._acquire_new_later(
+                    address, auth, deadline,
+                )
                 if connection_creator:
                     break
 
@@ -220,7 +318,8 @@ class AsyncIOPool(abc.ABC):
 
     @abc.abstractmethod
     async def acquire(
-        self, access_mode, timeout, database, bookmarks, liveness_check_timeout
+        self, access_mode, timeout, database, bookmarks, auth: AcquireAuth,
+        liveness_check_timeout
     ):
         """ Acquire a connection to a server that can satisfy a set of parameters.
 
@@ -229,6 +328,7 @@ class AsyncIOPool(abc.ABC):
             (excluding potential preparation like fetching routing tables).
         :param database:
         :param bookmarks:
+        :param auth:
         :param liveness_check_timeout:
         """
         ...
@@ -263,24 +363,24 @@ class AsyncIOPool(abc.ABC):
                     or connection.is_reset):
                 if cancelled is not None:
                     log.debug(
-                        "[#%04X]  _: <POOL> released unclean connection %s",
+                        "[#%04X]  _: <POOL> kill unclean connection %s",
                         connection.local_port, connection.connection_id
                     )
                     connection.kill()
                     continue
                 try:
                     log.debug(
-                        "[#%04X]  _: <POOL> released unclean connection %s",
+                        "[#%04X]  _: <POOL> release unclean connection %s",
                         connection.local_port, connection.connection_id
                     )
                     await connection.reset()
-                except (Neo4jError, DriverError, BoltError) as e:
+                except (Neo4jError, DriverError, BoltError) as exc:
                     log.debug("[#%04X]  _: <POOL> failed to reset connection "
-                              "on release: %r", connection.local_port, e)
-                except asyncio.CancelledError as e:
+                              "on release: %r", connection.local_port, exc)
+                except asyncio.CancelledError as exc:
                     log.debug("[#%04X]  _: <POOL> cancelled reset connection "
-                              "on release: %r", connection.local_port, e)
-                    cancelled = e
+                              "on release: %r", connection.local_port, exc)
+                    cancelled = exc
                     connection.kill()
         with self.lock:
             for connection in connections:
@@ -351,6 +451,27 @@ class AsyncIOPool(abc.ABC):
             "No write service available for pool {}".format(self)
         )
 
+    async def on_neo4j_error(self, error, connection):
+        assert isinstance(error, Neo4jError)
+        if error._unauthenticates_all_connections():
+            address = connection.unresolved_address
+            log.debug(
+                "[#0000]  _: <POOL> mark all connections to %r as "
+                "unauthenticated", address
+            )
+            with self.lock:
+                for connection in self.connections.get(address, ()):
+                    connection.mark_unauthenticated()
+        if error._requires_new_credentials():
+            await AsyncUtil.callback(
+                connection.auth_manager.on_auth_expired,
+                connection.auth
+            )
+        if (isinstance(error, TokenExpired)
+            and not isinstance(self.pool_config.auth, (AsyncStaticAuthManager,
+                                                       StaticAuthManager))):
+            error.__class__ = TokenExpiredRetryable
+
     async def close(self):
         """ Close all connections and empty the pool.
         This method is thread safe.
@@ -370,20 +491,19 @@ class AsyncIOPool(abc.ABC):
 class AsyncBoltPool(AsyncIOPool):
 
     @classmethod
-    def open(cls, address, *, auth, pool_config, workspace_config):
+    def open(cls, address, *, pool_config, workspace_config):
         """Create a new BoltPool
 
         :param address:
-        :param auth:
         :param pool_config:
         :param workspace_config:
         :returns: BoltPool
         """
 
-        async def opener(addr, deadline):
+        async def opener(addr, auth_manager, deadline):
             return await AsyncBolt.open(
-                addr, auth=auth, deadline=deadline, routing_context=None,
-                pool_config=pool_config
+                addr, auth_manager=auth_manager, deadline=deadline,
+                routing_context=None, pool_config=pool_config
             )
 
         pool = cls(opener, pool_config, workspace_config, address)
@@ -399,7 +519,8 @@ class AsyncBoltPool(AsyncIOPool):
                                           self.address)
 
     async def acquire(
-        self, access_mode, timeout, database, bookmarks, liveness_check_timeout
+        self, access_mode, timeout, database, bookmarks, auth: AcquireAuth,
+        liveness_check_timeout
     ):
         # The access_mode and database is not needed for a direct connection,
         # it's just there for consistency.
@@ -407,7 +528,7 @@ class AsyncBoltPool(AsyncIOPool):
                   "access_mode=%r, database=%r", access_mode, database)
         deadline = Deadline.from_timeout_or_deadline(timeout)
         return await self._acquire(
-            self.address, deadline, liveness_check_timeout
+            self.address, auth, deadline, liveness_check_timeout
         )
 
 
@@ -416,12 +537,11 @@ class AsyncNeo4jPool(AsyncIOPool):
     """
 
     @classmethod
-    def open(cls, *addresses, auth, pool_config, workspace_config,
+    def open(cls, *addresses, pool_config, workspace_config,
              routing_context=None):
         """Create a new Neo4jPool
 
         :param addresses: one or more address as positional argument
-        :param auth:
         :param pool_config:
         :param workspace_config:
         :param routing_context:
@@ -435,9 +555,9 @@ class AsyncNeo4jPool(AsyncIOPool):
             raise ConfigurationError("The key 'address' is reserved for routing context.")
         routing_context["address"] = str(address)
 
-        async def opener(addr, deadline):
+        async def opener(addr, auth_manager, deadline):
             return await AsyncBolt.open(
-                addr, auth=auth, deadline=deadline,
+                addr, auth_manager=auth_manager, deadline=deadline,
                 routing_context=routing_context, pool_config=pool_config
             )
 
@@ -478,7 +598,7 @@ class AsyncNeo4jPool(AsyncIOPool):
             return self.routing_tables[database]
 
     async def fetch_routing_info(
-        self, address, database, imp_user, bookmarks, acquisition_timeout
+        self, address, database, imp_user, bookmarks, auth, acquisition_timeout
     ):
         """ Fetch raw routing info from a given router address.
 
@@ -489,6 +609,7 @@ class AsyncNeo4jPool(AsyncIOPool):
         :type imp_user: str or None
         :param bookmarks: iterable of bookmark values after which the routing
                           info should be fetched
+        :param auth: auth
         :param acquisition_timeout: connection acquisition timeout
 
         :returns: list of routing records, or None if no connection
@@ -499,7 +620,10 @@ class AsyncNeo4jPool(AsyncIOPool):
         deadline = Deadline.from_timeout_or_deadline(acquisition_timeout)
         log.debug("[#0000]  _: <POOL> _acquire router connection, "
                   "database=%r, address=%r", database, address)
-        cx = await self._acquire(address, deadline, None)
+        if auth:
+            auth = copy(auth)
+            auth.force_auth = False
+        cx = await self._acquire(address, auth, deadline, None)
         try:
             routing_table = await cx.route(
                 database=database or self.workspace_config.database,
@@ -511,7 +635,8 @@ class AsyncNeo4jPool(AsyncIOPool):
         return routing_table
 
     async def fetch_routing_table(
-        self, *, address, acquisition_timeout, database, imp_user, bookmarks
+        self, *, address, acquisition_timeout, database, imp_user,
+        bookmarks, auth
     ):
         """ Fetch a routing table from a given router address.
 
@@ -523,6 +648,7 @@ class AsyncNeo4jPool(AsyncIOPool):
                          table
         :type imp_user: str or None
         :param bookmarks: bookmarks used when fetching routing table
+        :param auth: auth
 
         :returns: a new RoutingTable instance or None if the given router is
                  currently unable to provide routing information
@@ -530,7 +656,8 @@ class AsyncNeo4jPool(AsyncIOPool):
         new_routing_info = None
         try:
             new_routing_info = await self.fetch_routing_info(
-                address, database, imp_user, bookmarks, acquisition_timeout
+                address, database, imp_user, bookmarks, auth,
+                acquisition_timeout
             )
         except Neo4jError as e:
             # checks if the code is an error that is caused by the client. In
@@ -576,8 +703,8 @@ class AsyncNeo4jPool(AsyncIOPool):
         return new_routing_table
 
     async def _update_routing_table_from(
-        self, *routers, database, imp_user, bookmarks, acquisition_timeout,
-        database_callback
+        self, *routers, database, imp_user, bookmarks, auth,
+        acquisition_timeout, database_callback
     ):
         """ Try to update routing tables with the given routers.
 
@@ -593,7 +720,8 @@ class AsyncNeo4jPool(AsyncIOPool):
             ):
                 new_routing_table = await self.fetch_routing_table(
                     address=address, acquisition_timeout=acquisition_timeout,
-                    database=database, imp_user=imp_user, bookmarks=bookmarks
+                    database=database, imp_user=imp_user, bookmarks=bookmarks,
+                    auth=auth
                 )
                 if new_routing_table is not None:
                     new_database = new_routing_table.database
@@ -613,8 +741,8 @@ class AsyncNeo4jPool(AsyncIOPool):
         return False
 
     async def update_routing_table(
-        self, *, database, imp_user, bookmarks, acquisition_timeout=None,
-        database_callback=None
+        self, *, database, imp_user, bookmarks, auth=None,
+        acquisition_timeout=None, database_callback=None
     ):
         """ Update the routing table from the first router able to provide
         valid routing information.
@@ -624,6 +752,7 @@ class AsyncNeo4jPool(AsyncIOPool):
                          table
         :type imp_user: str or None
         :param bookmarks: bookmarks used when fetching routing table
+        :param auth: auth
         :param acquisition_timeout: connection acquisition timeout
         :param database_callback: A callback function that will be called with
             the database name as only argument when a new routing table has been
@@ -645,15 +774,15 @@ class AsyncNeo4jPool(AsyncIOPool):
                 # TODO: Test this state
                 if await self._update_routing_table_from(
                     self.address, database=database,
-                    imp_user=imp_user, bookmarks=bookmarks,
+                    imp_user=imp_user, bookmarks=bookmarks, auth=auth,
                     acquisition_timeout=acquisition_timeout,
                     database_callback=database_callback
                 ):
                     # Why is only the first initial routing address used?
                     return
             if await self._update_routing_table_from(
-                *(existing_routers - {self.address}),
-                database=database, imp_user=imp_user, bookmarks=bookmarks,
+                *(existing_routers - {self.address}), database=database,
+                imp_user=imp_user, bookmarks=bookmarks, auth=auth,
                 acquisition_timeout=acquisition_timeout,
                 database_callback=database_callback
             ):
@@ -662,7 +791,7 @@ class AsyncNeo4jPool(AsyncIOPool):
             if not prefer_initial_routing_address:
                 if await self._update_routing_table_from(
                     self.address, database=database,
-                    imp_user=imp_user, bookmarks=bookmarks,
+                    imp_user=imp_user, bookmarks=bookmarks, auth=auth,
                     acquisition_timeout=acquisition_timeout,
                     database_callback=database_callback
                 ):
@@ -681,7 +810,7 @@ class AsyncNeo4jPool(AsyncIOPool):
                 await super(AsyncNeo4jPool, self).deactivate(address)
 
     async def ensure_routing_table_is_fresh(
-        self, *, access_mode, database, imp_user, bookmarks,
+        self, *, access_mode, database, imp_user, bookmarks, auth=None,
         acquisition_timeout=None, database_callback=None
     ):
         """ Update the routing table if stale.
@@ -718,7 +847,7 @@ class AsyncNeo4jPool(AsyncIOPool):
 
             await self.update_routing_table(
                 database=database, imp_user=imp_user, bookmarks=bookmarks,
-                acquisition_timeout=acquisition_timeout,
+                auth=auth, acquisition_timeout=acquisition_timeout,
                 database_callback=database_callback
             )
             await self.update_connection_pool(database=database)
@@ -755,7 +884,8 @@ class AsyncNeo4jPool(AsyncIOPool):
         return choice(addresses_by_usage[min(addresses_by_usage)])
 
     async def acquire(
-        self, access_mode, timeout, database, bookmarks, liveness_check_timeout
+        self, access_mode, timeout, database, bookmarks,
+        auth: t.Optional[AcquireAuth], liveness_check_timeout
     ):
         if access_mode not in (WRITE_ACCESS, READ_ACCESS):
             raise ClientError("Non valid 'access_mode'; {}".format(access_mode))
@@ -775,7 +905,7 @@ class AsyncNeo4jPool(AsyncIOPool):
                   "access_mode=%r, database=%r", access_mode, database)
         await self.ensure_routing_table_is_fresh(
             access_mode=access_mode, database=database,
-            imp_user=None, bookmarks=bookmarks,
+            imp_user=None, bookmarks=bookmarks, auth=auth,
             acquisition_timeout=timeout
         )
 
@@ -794,7 +924,7 @@ class AsyncNeo4jPool(AsyncIOPool):
                 deadline = Deadline.from_timeout_or_deadline(timeout)
                 # should always be a resolved address
                 connection = await self._acquire(
-                    address, deadline, liveness_check_timeout
+                    address, auth, deadline, liveness_check_timeout,
                 )
             except (ServiceUnavailable, SessionExpired):
                 await self.deactivate(address=address)
