@@ -44,9 +44,10 @@ from .._conf import (
 )
 from .._meta import (
     deprecation_warn,
-    experimental,
     experimental_warn,
-    ExperimentalWarning,
+    preview,
+    preview_warn,
+    PreviewWarning,
     unclosed_resource_warn,
 )
 from .._work import EagerResult
@@ -72,6 +73,11 @@ from ..api import (
     URI_SCHEME_NEO4J_SECURE,
     URI_SCHEME_NEO4J_SELF_SIGNED_CERTIFICATE,
 )
+from ..auth_management import (
+    AuthManager,
+    AuthManagers,
+)
+from ..exceptions import Neo4jError
 from .bookmark_manager import (
     Neo4jBookmarkManager,
     TBmConsumer as _TBmConsumer,
@@ -91,6 +97,7 @@ if t.TYPE_CHECKING:
     import typing_extensions as te
 
     from .._api import T_RoutingControl
+    from ..api import _TAuth
 
 
     class _DefaultEnum(Enum):
@@ -115,7 +122,13 @@ class GraphDatabase:
             cls,
             uri: str,
             *,
-            auth: t.Union[t.Tuple[t.Any, t.Any], Auth, None] = ...,
+            auth: t.Union[
+                # work around https://github.com/sphinx-doc/sphinx/pull/10880
+                # make sure TAuth is resolved in the docs
+                # TAuth,
+                t.Union[t.Tuple[t.Any, t.Any], Auth, None],
+                AuthManager,
+            ] = ...,
             max_connection_lifetime: float = ...,
             max_connection_pool_size: int = ...,
             connection_timeout: float = ...,
@@ -159,7 +172,13 @@ class GraphDatabase:
         @classmethod
         def driver(
             cls, uri: str, *,
-            auth: t.Union[t.Tuple[t.Any, t.Any], Auth, None] = None,
+            auth: t.Union[
+                # work around https://github.com/sphinx-doc/sphinx/pull/10880
+                # make sure TAuth is resolved in the docs
+                # TAuth,
+                t.Union[t.Tuple[t.Any, t.Any], Auth, None],
+                AuthManager,
+            ] = None,
             **config
         ) -> Driver:
             """Create a driver.
@@ -175,6 +194,18 @@ class GraphDatabase:
 
             driver_type, security_type, parsed = parse_neo4j_uri(uri)
 
+            if not isinstance(auth, AuthManager):
+                with warnings.catch_warnings():
+                    warnings.filterwarnings(
+                        "ignore", message=r".*\bAuth managers\b.*",
+                        category=PreviewWarning
+                    )
+                    auth = AuthManagers.static(auth)
+            else:
+                preview_warn("Auth managers are a preview feature.",
+                             stack_level=2)
+            config["auth"] = auth
+
             # TODO: 6.0 - remove "trust" config option
             if "trust" in config.keys():
                 if config["trust"] not in (
@@ -252,17 +283,13 @@ class GraphDatabase:
                     #     'Routing parameters are not supported with scheme '
                     #     '"bolt". Given URI "{}".'.format(uri)
                     # )
-                return cls.bolt_driver(parsed.netloc, auth=auth, **config)
+                return cls.bolt_driver(parsed.netloc, **config)
             # else driver_type == DRIVER_NEO4J
             routing_context = parse_routing_context(parsed.query)
-            return cls.neo4j_driver(parsed.netloc, auth=auth,
+            return cls.neo4j_driver(parsed.netloc,
                                     routing_context=routing_context, **config)
 
     @classmethod
-    @experimental(
-        "The bookmark manager feature is experimental. "
-        "It might be changed or removed any time even without prior notice."
-    )
     def bookmark_manager(
         cls,
         initial_bookmarks: t.Union[None, Bookmarks, t.Iterable[str]] = None,
@@ -323,9 +350,6 @@ class GraphDatabase:
 
         :returns: A default implementation of :class:`BookmarkManager`.
 
-        **This is experimental.** (See :ref:`filter-warnings-ref`)
-        It might be changed or removed any time even without prior notice.
-
         .. versionadded:: 5.0
 
         .. versionchanged:: 5.3
@@ -339,6 +363,8 @@ class GraphDatabase:
               an argument.
             * ``bookmarks_consumer`` no longer receives the database name as
               an argument.
+
+        .. versionchanged:: 5.8 stabilized from experimental
         """
         return Neo4jBookmarkManager(
             initial_bookmarks=initial_bookmarks,
@@ -347,7 +373,7 @@ class GraphDatabase:
         )
 
     @classmethod
-    def bolt_driver(cls, target, *, auth=None, **config):
+    def bolt_driver(cls, target, **config):
         """ Create a driver for direct Bolt server access that uses
         socket I/O and thread-based concurrency.
         """
@@ -357,13 +383,13 @@ class GraphDatabase:
         )
 
         try:
-            return BoltDriver.open(target, auth=auth, **config)
+            return BoltDriver.open(target, **config)
         except (BoltHandshakeError, BoltSecurityError) as error:
             from ..exceptions import ServiceUnavailable
             raise ServiceUnavailable(str(error)) from error
 
     @classmethod
-    def neo4j_driver(cls, *targets, auth=None, routing_context=None, **config):
+    def neo4j_driver(cls, *targets, routing_context=None, **config):
         """ Create a driver for routing-capable Neo4j service access
         that uses socket I/O and thread-based concurrency.
         """
@@ -373,7 +399,7 @@ class GraphDatabase:
         )
 
         try:
-            return Neo4jDriver.open(*targets, auth=auth, routing_context=routing_context, **config)
+            return Neo4jDriver.open(*targets, routing_context=routing_context, **config)
         except (BoltHandshakeError, BoltSecurityError) as error:
             from ..exceptions import ServiceUnavailable
             raise ServiceUnavailable(str(error)) from error
@@ -381,9 +407,9 @@ class GraphDatabase:
 
 class _Direct:
 
+    # TODO: 6.0 - those attributes should be private
     default_host = "localhost"
     default_port = 7687
-
     default_target = ":"
 
     def __init__(self, address):
@@ -406,9 +432,9 @@ class _Direct:
 
 class _Routing:
 
+    # TODO: 6.0 - those attributes should be private
     default_host = "localhost"
     default_port = 7687
-
     default_targets = ": :17601 :17687"
 
     def __init__(self, initial_addresses):
@@ -446,12 +472,7 @@ class Driver:
         assert default_workspace_config is not None
         self._pool = pool
         self._default_workspace_config = default_workspace_config
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore",
-                                    message=r".*\bbookmark manager\b.*",
-                                    category=ExperimentalWarning)
-            self._query_bookmark_manager = \
-                GraphDatabase.bookmark_manager()
+        self._query_bookmark_manager = GraphDatabase.bookmark_manager()
 
     def __enter__(self) -> Driver:
         return self
@@ -480,6 +501,9 @@ class Driver:
         return bool(self._pool.pool_config.encrypted)
 
     def _prepare_session_config(self, **config):
+        if "auth" in config:
+            preview_warn("User switching is a preview feature.",
+                         stack_level=3)
         _normalize_notifications_config(config)
         return config
 
@@ -497,6 +521,7 @@ class Driver:
             default_access_mode: str = ...,
             bookmark_manager: t.Union[BookmarkManager,
                                       BookmarkManager, None] = ...,
+            auth: _TAuth = ...,
             notifications_min_severity: t.Optional[
                 T_NotificationMinimumSeverity
             ] = ...,
@@ -539,14 +564,15 @@ class Driver:
     @t.overload
     def execute_query(
         self,
-        query_: str,
+        query_: te.LiteralString,
         parameters_: t.Optional[t.Dict[str, t.Any]] = None,
-        routing_: T_RoutingControl = RoutingControl.WRITERS,
+        routing_: T_RoutingControl = RoutingControl.WRITE,
         database_: t.Optional[str] = None,
         impersonated_user_: t.Optional[str] = None,
         bookmark_manager_: t.Union[
             BookmarkManager, BookmarkManager, None
         ] = ...,
+        auth_: _TAuth = None,
         result_transformer_: t.Callable[
             [Result], t.Union[EagerResult]
         ] = ...,
@@ -557,14 +583,15 @@ class Driver:
     @t.overload
     def execute_query(
         self,
-        query_: str,
+        query_: te.LiteralString,
         parameters_: t.Optional[t.Dict[str, t.Any]] = None,
-        routing_: T_RoutingControl = RoutingControl.WRITERS,
+        routing_: T_RoutingControl = RoutingControl.WRITE,
         database_: t.Optional[str] = None,
         impersonated_user_: t.Optional[str] = None,
         bookmark_manager_: t.Union[
             BookmarkManager, BookmarkManager, None
         ] = ...,
+        auth_: _TAuth = None,
         result_transformer_: t.Callable[
             [Result], t.Union[_T]
         ] = ...,
@@ -572,21 +599,18 @@ class Driver:
     ) -> _T:
         ...
 
-    @experimental(
-        "Driver.execute_query is experimental. "
-        "It might be changed or removed any time even without prior notice."
-    )
     def execute_query(
         self,
-        query_: str,
+        query_: te.LiteralString,
         parameters_: t.Optional[t.Dict[str, t.Any]] = None,
-        routing_: T_RoutingControl = RoutingControl.WRITERS,
+        routing_: T_RoutingControl = RoutingControl.WRITE,
         database_: t.Optional[str] = None,
         impersonated_user_: t.Optional[str] = None,
         bookmark_manager_: t.Union[
             BookmarkManager, BookmarkManager, None,
             te.Literal[_DefaultEnum.default]
         ] = _default,
+        auth_: _TAuth = None,
         result_transformer_: t.Callable[
             [Result], t.Union[t.Any]
         ] = Result.to_eager_result,
@@ -608,7 +632,7 @@ class Driver:
 
             def execute_query(
                 query_, parameters_, routing_, database_, impersonated_user_,
-                bookmark_manager_, result_transformer_, **kwargs
+                bookmark_manager_, auth_, result_transformer_, **kwargs
             ):
                 def work(tx):
                     result = tx.run(query_, parameters_, **kwargs)
@@ -618,10 +642,11 @@ class Driver:
                     database=database_,
                     impersonated_user=impersonated_user_,
                     bookmark_manager=bookmark_manager_,
+                    auth=auth_,
                 ) as session:
-                    if routing_ == RoutingControl.WRITERS:
+                    if routing_ == RoutingControl.WRITE:
                         return session.execute_write(work)
-                    elif routing_ == RoutingControl.READERS:
+                    elif routing_ == RoutingControl.READ:
                         return session.execute_read(work)
 
         Usage example::
@@ -636,7 +661,7 @@ class Driver:
                 records, summary, keys = driver.execute_query(
                     "MATCH (p:Person {age: $age}) RETURN p.name",
                     {"age": 42},
-                    routing_=neo4j.RoutingControl.READERS,  # or just "r"
+                    routing_=neo4j.RoutingControl.READ,  # or just "r"
                     database_="neo4j",
                 )
                 assert keys == ["p.name"]  # not needed, just for illustration
@@ -653,13 +678,14 @@ class Driver:
             def example(driver: neo4j.Driver) -> int:
                 \"""Call all young people "My dear" and get their count.\"""
                 record = driver.execute_query(
-                    "MATCH (p:Person) WHERE p.age <= 15 "
+                    "MATCH (p:Person) WHERE p.age <= $age "
                     "SET p.nickname = 'My dear' "
                     "RETURN count(*)",
                     # optional routing parameter, as write is default
-                    # routing_=neo4j.RoutingControl.WRITERS,  # or just "w",
+                    # routing_=neo4j.RoutingControl.WRITE,  # or just "w",
                     database_="neo4j",
                     result_transformer_=neo4j.Result.single,
+                    age=15,
                 )
                 assert record is not None  # for typechecking and illustration
                 count = record[0]
@@ -696,6 +722,20 @@ class Driver:
 
             See also the Session config :ref:`impersonated-user-ref`.
         :type impersonated_user_: typing.Optional[str]
+        :param auth_:
+            Authentication information to use for this query.
+
+            By default, the driver configuration is used.
+
+            **This is a preview** (see :ref:`filter-warnings-ref`).
+            It might be changed without following the deprecation policy.
+            See also
+            https://github.com/neo4j/neo4j-python-driver/wiki/preview-features
+
+            See also the Session config :ref:`session-auth-ref`.
+        :type auth_: typing.Union[
+            typing.Tuple[typing.Any, typing.Any], neo4j.Auth, None
+        ]
         :param result_transformer_:
             A function that gets passed the :class:`neo4j.Result` object
             resulting from the query and converts it to a different type. The
@@ -764,26 +804,27 @@ class Driver:
             If present, the bookmark manager is used to keep the query causally
             consistent with all work executed using the same bookmark manager.
 
-            Defaults to the driver's :attr:`.query_bookmark_manager`.
+            Defaults to the driver's :attr:`.execute_query_bookmark_manager`.
 
-            Pass :const:`None` to disable causal consistency.
+            Pass :data:`None` to disable causal consistency.
         :type bookmark_manager_:
-            typing.Union[neo4j.BookmarkManager, neo4j.BookmarkManager,
-                         None]
+            typing.Union[BookmarkManager, BookmarkManager, None]
         :param kwargs: additional keyword parameters. None of these can end
             with a single underscore. This is to avoid collisions with the
             keyword configuration parameters of this method. If you need to
             pass such a parameter, use the ``parameters_`` parameter instead.
-            These take precedence over parameters passed as ``parameters_``.
+            Parameters passed as kwargs take precedence over those passed in
+            ``parameters_``.
         :type kwargs: typing.Any
 
         :returns: the result of the ``result_transformer``
         :rtype: T
 
-        **This is experimental.** (See :ref:`filter-warnings-ref`)
-        It might be changed or removed any time even without prior notice.
-
         .. versionadded:: 5.5
+
+        .. versionchanged:: 5.8
+            * Added the ``auth_`` parameter.
+            * Stabilized from experimental.
         """
         invalid_kwargs = [k for k in kwargs if
                           k[-2:-1] != "_" and k[-1:] == "_"]
@@ -803,15 +844,16 @@ class Driver:
 
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore",
-                                    message=r".*\bbookmark_manager\b.*",
-                                    category=ExperimentalWarning)
+                                    message=r"^User switching\b.*",
+                                    category=PreviewWarning)
             session = self.session(database=database_,
                                    impersonated_user=impersonated_user_,
-                                   bookmark_manager=bookmark_manager_)
+                                   bookmark_manager=bookmark_manager_,
+                                   auth=auth_)
         with session:
-            if routing_ == RoutingControl.WRITERS:
+            if routing_ == RoutingControl.WRITE:
                 executor = session.execute_write
-            elif routing_ == RoutingControl.READERS:
+            elif routing_ == RoutingControl.READ:
                 executor = session.execute_read
             else:
                 raise ValueError("Invalid routing control value: %r"
@@ -821,11 +863,7 @@ class Driver:
             )
 
     @property
-    @experimental(
-        "Driver.query_bookmark_manager is experimental. "
-        "It might be changed or removed any time even without prior notice."
-    )
-    def query_bookmark_manager(self) -> BookmarkManager:
+    def execute_query_bookmark_manager(self) -> BookmarkManager:
         """The driver's default query bookmark manager.
 
         This is the default :class:`BookmarkManager` used by
@@ -835,7 +873,7 @@ class Driver:
             def example(driver: neo4j.Driver) -> None:
                 driver.execute_query("<QUERY 1>")
                 with driver.session(
-                    bookmark_manager=driver.query_bookmark_manager
+                    bookmark_manager=driver.execute_query_bookmark_manager
                 ) as session:
                     # every query inside this session will be causally chained
                     # (i.e., can read what was written by <QUERY 1>)
@@ -844,10 +882,12 @@ class Driver:
                 # (i.e., can read what was written by <QUERY 2>)
                 driver.execute_query("<QUERY 3>")
 
-        **This is experimental.** (See :ref:`filter-warnings-ref`)
-        It might be changed or removed any time even without prior notice.
-
         .. versionadded:: 5.5
+
+        .. versionchanged:: 5.8
+            * Renamed from ``query_bookmark_manager`` to
+              ``execute_query_bookmark_manager``.
+            * Stabilized from experimental.
         """
         return self._query_bookmark_manager
 
@@ -868,6 +908,7 @@ class Driver:
             default_access_mode: str = ...,
             bookmark_manager: t.Union[BookmarkManager,
                                       BookmarkManager, None] = ...,
+            auth: t.Union[Auth, t.Tuple[t.Any, t.Any]] = ...,
             notifications_min_severity: t.Optional[
                 T_NotificationMinimumSeverity
             ] = ...,
@@ -884,7 +925,6 @@ class Driver:
 
     else:
 
-        # TODO: 6.0 - remove config argument
         def verify_connectivity(self, **config) -> None:
             """Verify that the driver can establish a connection to the server.
 
@@ -903,7 +943,7 @@ class Driver:
                     They might be changed or removed in any future version
                     without prior notice.
 
-            :raises DriverError: if the driver cannot connect to the remote.
+            :raises Exception: if the driver cannot connect to the remote.
                 Use the exception to further understand the cause of the
                 connectivity problem.
 
@@ -919,8 +959,7 @@ class Driver:
                     "changed or removed in any future version without prior "
                     "notice."
                 )
-            with self.session(**config) as session:
-                session._get_server_info()
+            self._get_server_info()
 
     if t.TYPE_CHECKING:
 
@@ -939,6 +978,7 @@ class Driver:
             default_access_mode: str = ...,
             bookmark_manager: t.Union[BookmarkManager,
                                       BookmarkManager, None] = ...,
+            auth: t.Union[Auth, t.Tuple[t.Any, t.Any]] = ...,
             notifications_min_severity: t.Optional[
                 T_NotificationMinimumSeverity
             ] = ...,
@@ -977,7 +1017,7 @@ class Driver:
                     They might be changed or removed in any future version
                     without prior notice.
 
-            :raises DriverError: if the driver cannot connect to the remote.
+            :raises Exception: if the driver cannot connect to the remote.
                 Use the exception to further understand the cause of the
                 connectivity problem.
 
@@ -986,14 +1026,12 @@ class Driver:
             if config:
                 experimental_warn(
                     "All configuration key-word arguments to "
-                    "verify_connectivity() are experimental. They might be "
+                    "get_server_info() are experimental. They might be "
                     "changed or removed in any future version without prior "
                     "notice."
                 )
-            with self.session(**config) as session:
-                return session._get_server_info()
+            return self._get_server_info()
 
-    @experimental("Feature support query, based on Bolt protocol version and Neo4j server version will change in the future.")
     def supports_multi_db(self) -> bool:
         """ Check if the server or cluster supports multi-databases.
 
@@ -1001,14 +1039,142 @@ class Driver:
             supports multi-databases, otherwise false.
 
         .. note::
-            Feature support query, based on Bolt Protocol Version and Neo4j
-            server version will change in the future.
+            Feature support query based solely on the Bolt protocol version.
+            The feature might still be disabled on the server side even if this
+            function return :const:`True`. It just guarantees that the driver
+            won't throw a :exc:`ConfigurationError` when trying to use this
+            driver feature.
         """
         with self.session() as session:
             session._connect(READ_ACCESS)
             assert session._connection
             return session._connection.supports_multiple_databases
 
+    if t.TYPE_CHECKING:
+
+        def verify_authentication(
+            self,
+            auth: t.Union[Auth, t.Tuple[t.Any, t.Any], None] = None,
+            # all other arguments are experimental
+            # they may be change or removed any time without prior notice
+            session_connection_timeout: float = ...,
+            connection_acquisition_timeout: float = ...,
+            max_transaction_retry_time: float = ...,
+            database: t.Optional[str] = ...,
+            fetch_size: int = ...,
+            impersonated_user: t.Optional[str] = ...,
+            bookmarks: t.Union[t.Iterable[str], Bookmarks, None] = ...,
+            default_access_mode: str = ...,
+            bookmark_manager: t.Union[
+                BookmarkManager, BookmarkManager, None
+            ] = ...,
+
+            # undocumented/unsupported options
+            initial_retry_delay: float = ...,
+            retry_delay_multiplier: float = ...,
+            retry_delay_jitter_factor: float = ...
+        ) -> bool:
+            ...
+
+    else:
+
+        @preview("User switching is a preview feature.")
+        def verify_authentication(
+            self,
+            auth: t.Union[Auth, t.Tuple[t.Any, t.Any], None] = None,
+            **config
+        ) -> bool:
+            """Verify that the authentication information is valid.
+
+            Like :meth:`.verify_connectivity`, but for checking authentication.
+
+            Try to establish a working read connection to the remote server or
+            a member of a cluster and exchange some data. In a cluster, there
+            is no guarantee about which server will be contacted. If the data
+            exchange is successful and the authentication information is valid,
+            :const:`True` is returned. Otherwise, the error will be matched
+            against a list of known authentication errors. If the error is on
+            that list, :const:`False` is returned indicating that the
+            authentication information is invalid. Otherwise, the error is
+            re-raised.
+
+            :param auth: authentication information to verify.
+                Same as the session config :ref:`auth-ref`.
+            :param config: accepts the same configuration key-word arguments as
+                :meth:`session`.
+
+                .. warning::
+                    All configuration key-word arguments (except ``auth``) are
+                    experimental. They might be changed or removed in any
+                    future version without prior notice.
+
+            :raises Exception: if the driver cannot connect to the remote.
+                Use the exception to further understand the cause of the
+                connectivity problem.
+
+            **This is a preview** (see :ref:`filter-warnings-ref`).
+            It might be changed without following the deprecation policy.
+            See also
+            https://github.com/neo4j/neo4j-python-driver/wiki/preview-features
+
+            .. versionadded:: 5.8
+            """
+            if config:
+                experimental_warn(
+                    "All configuration key-word arguments but auth to "
+                    "verify_authentication() are experimental. They might be "
+                    "changed or removed in any future version without prior "
+                    "notice."
+                )
+            config["auth"] = auth
+            if "database" not in config:
+                config["database"] = "system"
+            try:
+                with warnings.catch_warnings():
+                    warnings.filterwarnings(
+                        "ignore", message=r"^User switching\b.*",
+                        category=PreviewWarning
+                )
+                    session = self.session(**config)
+                with session as session:
+                    session._verify_authentication()
+            except Neo4jError as exc:
+                if exc.code in (
+                    "Neo.ClientError.Security.CredentialsExpired",
+                    "Neo.ClientError.Security.Forbidden",
+                    "Neo.ClientError.Security.TokenExpired",
+                    "Neo.ClientError.Security.Unauthorized",
+                ):
+                    return False
+                raise
+            return True
+
+
+    def supports_session_auth(self) -> bool:
+        """Check if the remote supports connection re-authentication.
+
+        :returns: Returns true if the server or cluster the driver connects to
+            supports re-authentication of existing connections, otherwise
+            false.
+
+        .. note::
+            Feature support query based solely on the Bolt protocol version.
+            The feature might still be disabled on the server side even if this
+            function return :const:`True`. It just guarantees that the driver
+            won't throw a :exc:`ConfigurationError` when trying to use this
+            driver feature.
+
+        .. versionadded:: 5.8
+        """
+        with self.session() as session:
+            session._connect(READ_ACCESS)
+            assert session._connection
+            return session._connection.supports_re_auth
+
+    def _get_server_info(self, **config) -> ServerInfo:
+        with self.session(**config) as session:
+            return session._get_server_info()
+
 
 def _work(
     tx: ManagedTransaction,
@@ -1018,11 +1184,7 @@ def _work(
 ) -> _T:
     res = tx.run(query, parameters)
     if transformer is Result.to_eager_result:
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore",
-                                    message=r".*\bto_eager_result\b.*",
-                                    category=ExperimentalWarning)
-            return transformer(res)
+        return transformer(res)
     return transformer(res)
 
 
@@ -1039,7 +1201,7 @@ class BoltDriver(_Direct, Driver):
     """
 
     @classmethod
-    def open(cls, target, *, auth=None, **config):
+    def open(cls, target, **config):
         """
         :param target:
         :param auth:
@@ -1051,7 +1213,7 @@ class BoltDriver(_Direct, Driver):
         from .io import BoltPool
         address = cls.parse_target(target)
         pool_config, default_workspace_config = Config.consume_chain(config, PoolConfig, WorkspaceConfig)
-        pool = BoltPool.open(address, auth=auth, pool_config=pool_config, workspace_config=default_workspace_config)
+        pool = BoltPool.open(address, pool_config=pool_config, workspace_config=default_workspace_config)
         return cls(pool, default_workspace_config)
 
     def __init__(self, pool, default_workspace_config):
@@ -1087,11 +1249,11 @@ class Neo4jDriver(_Routing, Driver):
     """
 
     @classmethod
-    def open(cls, *targets, auth=None, routing_context=None, **config):
+    def open(cls, *targets, routing_context=None, **config):
         from .io import Neo4jPool
         addresses = cls.parse_targets(*targets)
         pool_config, default_workspace_config = Config.consume_chain(config, PoolConfig, WorkspaceConfig)
-        pool = Neo4jPool.open(*addresses, auth=auth, routing_context=routing_context, pool_config=pool_config, workspace_config=default_workspace_config)
+        pool = Neo4jPool.open(*addresses, routing_context=routing_context, pool_config=pool_config, workspace_config=default_workspace_config)
         return cls(pool, default_workspace_config)
 
     def __init__(self, pool, default_workspace_config):
