@@ -25,6 +25,7 @@ from logging import getLogger
 from time import perf_counter
 
 from ..._async_compat.network import BoltSocket
+from ..._async_compat.util import Util
 from ..._codec.hydration import v1 as hydration_v1
 from ..._codec.packstream import v1 as packstream_v1
 from ..._conf import PoolConfig
@@ -33,8 +34,8 @@ from ..._exceptions import (
     BoltError,
     BoltHandshakeError,
 )
-from ..._meta import get_user_agent
-from ...addressing import Address
+from ..._meta import USER_AGENT
+from ...addressing import ResolvedAddress
 from ...api import (
     ServerInfo,
     Version,
@@ -58,6 +59,20 @@ from ._common import (
 log = getLogger("neo4j")
 
 
+class ServerStateManagerBase(abc.ABC):
+    @abc.abstractmethod
+    def __init__(self, init_state, on_change=None):
+        ...
+
+    @abc.abstractmethod
+    def transition(self, message, metadata):
+        ...
+
+    @abc.abstractmethod
+    def failed(self):
+        ...
+
+
 class Bolt:
     """ Server connection for Bolt protocol.
 
@@ -104,13 +119,17 @@ class Bolt:
     most_recent_qid = None
 
     def __init__(self, unresolved_address, sock, max_connection_lifetime, *,
-                 auth=None, user_agent=None, routing_context=None,
-                 notifications_min_severity=None, notifications_disabled_categories=None):
+                 auth=None, auth_manager=None, user_agent=None,
+                 routing_context=None, notifications_min_severity=None,
+                 notifications_disabled_categories=None):
         self.unresolved_address = unresolved_address
         self.socket = sock
         self.local_port = self.socket.getsockname()[1]
-        self.server_info = ServerInfo(Address(sock.getpeername()),
-                                      self.PROTOCOL_VERSION)
+        self.server_info = ServerInfo(
+            ResolvedAddress(sock.getpeername(),
+                            host_name=unresolved_address.host),
+            self.PROTOCOL_VERSION
+        )
         # so far `connection.recv_timeout_seconds` is the only available
         # configuration hint that exists. Therefore, all hints can be stored at
         # connection level. This might change in the future.
@@ -135,28 +154,11 @@ class Bolt:
         if user_agent:
             self.user_agent = user_agent
         else:
-            self.user_agent = get_user_agent()
+            self.user_agent = USER_AGENT
 
-        # Determine auth details
-        if not auth:
-            self.auth_dict = {}
-        elif isinstance(auth, tuple) and 2 <= len(auth) <= 3:
-            from ...api import Auth
-            self.auth_dict = vars(Auth("basic", *auth))
-        else:
-            try:
-                self.auth_dict = vars(auth)
-            except (KeyError, TypeError):
-                raise AuthError("Cannot determine auth details from %r" % auth)
-
-        # Check for missing password
-        try:
-            credentials = self.auth_dict["credentials"]
-        except KeyError:
-            pass
-        else:
-            if credentials is None:
-                raise AuthError("Password cannot be None")
+        self.auth = auth
+        self.auth_dict = self._to_auth_dict(auth)
+        self.auth_manager = auth_manager
 
         self.notifications_min_severity = notifications_min_severity
         self.notifications_disabled_categories = \
@@ -166,6 +168,24 @@ class Bolt:
         if not asyncio.iscoroutinefunction(self.close):
             self.close()
 
+    @abc.abstractmethod
+    def _get_server_state_manager(self) -> ServerStateManagerBase:
+        ...
+
+    @classmethod
+    def _to_auth_dict(cls, auth):
+        # Determine auth details
+        if not auth:
+            return {}
+        elif isinstance(auth, tuple) and 2 <= len(auth) <= 3:
+            from ...api import Auth
+            return vars(Auth("basic", *auth))
+        else:
+            try:
+                return vars(auth)
+            except (KeyError, TypeError):
+                raise AuthError("Cannot determine auth details from %r" % auth)
+
     @property
     def connection_id(self):
         return self.server_info._metadata.get("connection_id", "<unknown id>")
@@ -187,6 +207,20 @@ class Bolt:
         """
         pass
 
+    @property
+    @abc.abstractmethod
+    def supports_re_auth(self):
+        """Whether the connection version supports re-authentication."""
+        pass
+
+    def assert_re_auth_support(self):
+        if not self.supports_re_auth:
+            raise ConfigurationError(
+                "User switching is not supported for Bolt "
+                f"Protocol {self.PROTOCOL_VERSION!r}. Server Agent "
+                f"{self.server_info.agent!r}"
+            )
+
     @property
     @abc.abstractmethod
     def supports_notification_filtering(self):
@@ -229,6 +263,7 @@ class Bolt:
             Bolt5x0,
             Bolt5x1,
             Bolt5x2,
+            Bolt5x3,
         )
 
         handlers = {
@@ -241,6 +276,7 @@ class Bolt:
             Bolt5x0.PROTOCOL_VERSION: Bolt5x0,
             Bolt5x1.PROTOCOL_VERSION: Bolt5x1,
             Bolt5x2.PROTOCOL_VERSION: Bolt5x2,
+            Bolt5x3.PROTOCOL_VERSION: Bolt5x3,
         }
 
         if protocol_version is None:
@@ -318,13 +354,13 @@ class Bolt:
     # [bolt-version-bump] search tag when changing bolt version support
     @classmethod
     def open(
-        cls, address, *, auth=None, deadline=None, routing_context=None,
-        pool_config=None
+        cls, address, *, auth_manager=None, deadline=None,
+        routing_context=None, pool_config=None
     ):
         """Open a new Bolt connection to a given server address.
 
         :param address:
-        :param auth:
+        :param auth_manager:
         :param deadline: how long to wait for the connection to be established
         :param routing_context: dict containing routing context
         :param pool_config:
@@ -355,7 +391,10 @@ class Bolt:
 
         # Carry out Bolt subclass imports locally to avoid circular dependency
         # issues.
-        if protocol_version == (5, 2):
+        if protocol_version == (5, 3):
+            from ._bolt5 import Bolt5x3
+            bolt_cls = Bolt5x3
+        elif protocol_version == (5, 2):
             from ._bolt5 import Bolt5x2
             bolt_cls = Bolt5x2
         elif protocol_version == (5, 1):
@@ -386,7 +425,7 @@ class Bolt:
             from ._bolt3 import Bolt3
             bolt_cls = Bolt3
         else:
-            log.debug("[#%04X]  S: <CLOSE>", s.getsockname()[1])
+            log.debug("[#%04X]  C: <CLOSE>", s.getsockname()[1])
             BoltSocket.close_socket(s)
 
             supported_versions = cls.protocol_handlers().keys()
@@ -397,9 +436,23 @@ class Bolt:
                 address=address, request_data=handshake, response_data=data
             )
 
+        try:
+            auth = Util.callback(auth_manager.get_auth)
+        except asyncio.CancelledError as e:
+            log.debug("[#%04X]  C: <KILL> open auth manager failed: %r",
+                      s.getsockname()[1], e)
+            s.kill()
+            raise
+        except Exception as e:
+            log.debug("[#%04X]  C: <CLOSE> open auth manager failed: %r",
+                      s.getsockname()[1], e)
+            s.close()
+            raise
+
         connection = bolt_cls(
             address, s, pool_config.max_connection_lifetime, auth=auth,
-            user_agent=pool_config.user_agent, routing_context=routing_context,
+            auth_manager=auth_manager, user_agent=pool_config.user_agent,
+            routing_context=routing_context,
             notifications_min_severity=pool_config.notifications_min_severity,
             notifications_disabled_categories=
                 pool_config.notifications_disabled_categories
@@ -448,6 +501,45 @@ class Bolt:
         """
         pass
 
+    @abc.abstractmethod
+    def logon(self, dehydration_hooks=None, hydration_hooks=None):
+        """Append a LOGON message to the outgoing queue."""
+        pass
+
+    @abc.abstractmethod
+    def logoff(self, dehydration_hooks=None, hydration_hooks=None):
+        """Append a LOGOFF message to the outgoing queue."""
+        pass
+
+    def mark_unauthenticated(self):
+        """Mark the connection as unauthenticated."""
+        self.auth_dict = {}
+
+    def re_auth(
+        self, auth, auth_manager, force=False,
+        dehydration_hooks=None, hydration_hooks=None,
+    ):
+        """Append LOGON, LOGOFF to the outgoing queue.
+
+        If auth is the same as the current auth, this method does nothing.
+
+        :returns: whether the auth was changed
+        """
+        new_auth_dict = self._to_auth_dict(auth)
+        if not force and new_auth_dict == self.auth_dict:
+            self.auth_manager = auth_manager
+            self.auth = auth
+            return False
+        self.logoff(dehydration_hooks=dehydration_hooks,
+                     hydration_hooks=hydration_hooks)
+        self.auth_dict = new_auth_dict
+        self.auth_manager = auth_manager
+        self.auth = auth
+        self.logon(dehydration_hooks=dehydration_hooks,
+                    hydration_hooks=hydration_hooks)
+        return True
+
+
     @abc.abstractmethod
     def route(
         self, database=None, imp_user=None, bookmarks=None,
@@ -750,7 +842,7 @@ class Bolt:
         user_cancelled = isinstance(error, asyncio.CancelledError)
 
         if error:
-            log.debug("[#%04X] _: <CONNECTION> error: %r", self.local_port,
+            log.debug("[#%04X]  _: <CONNECTION> error: %r", self.local_port,
                       error)
         if not user_cancelled:
             log.error(message)
@@ -767,7 +859,7 @@ class Bolt:
             # remove the connection from the pool, nor to try to close the
             # connection again.
             self.close()
-            if self.pool:
+            if self.pool and not self._get_server_state_manager().failed():
                 self.pool.deactivate(address=self.unresolved_address)
 
         # Iterate through the outstanding responses, and if any correspond
