@@ -15,9 +15,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
 """ Base classes and helpers.
 """
 
+
 from __future__ import annotations
 
 import abc
@@ -103,10 +105,21 @@ class Auth:
         if parameters:
             self.parameters = parameters
 
+    def __eq__(self, other):
+        if not isinstance(other, Auth):
+            return NotImplemented
+        return vars(self) == vars(other)
+
 
 # For backwards compatibility
 AuthToken = Auth
 
+# if t.TYPE_CHECKING:
+# commented out as work around for
+# https://github.com/sphinx-doc/sphinx/pull/10880
+# make sure TAuth is resolved in the docs, else they're pretty useless
+_TAuth = t.Union[t.Tuple[t.Any, t.Any], Auth, None]
+
 
 def basic_auth(
     user: str, password: str, realm: t.Optional[str] = None
@@ -397,9 +410,6 @@ class BookmarkManager(_Protocol, metaclass=abc.ABCMeta):
     .. note::
         All methods must be concurrency safe.
 
-    **This is experimental.**
-    It might be changed or removed any time even without prior notice.
-
     .. versionadded:: 5.0
 
     .. versionchanged:: 5.3
@@ -411,6 +421,8 @@ class BookmarkManager(_Protocol, metaclass=abc.ABCMeta):
         * :meth:`.get_bookmarks` has no longer a ``database`` argument.
         * The ``get_all_bookmarks`` method was removed.
         * The ``forget`` method was removed.
+
+    .. versionchanged:: 5.8 stabilized from experimental
     """
 
     @abc.abstractmethod
@@ -442,13 +454,12 @@ class AsyncBookmarkManager(_Protocol, metaclass=abc.ABCMeta):
     The driver comes with a default implementation of the async bookmark
     manager accessible through :attr:`.AsyncGraphDatabase.bookmark_manager()`.
 
-    **This is experimental.**
-    It might be changed or removed any time even without prior notice.
-
     .. versionadded:: 5.0
 
     .. versionchanged:: 5.3
         See :class:`.BookmarkManager` for changes.
+
+    .. versionchanged:: 5.8 stabilized from experimental
     """
 
     @abc.abstractmethod
